@@ -12,7 +12,7 @@
 #' @param case integer parameter in \{1,2,3,4\}: (1) none of the endpoints is death; (2) endpoint 2 is death; (3) endpoint 1 is death; (4) both endpoints are death by different causes.
 #' @param copula character indicating the copula to be used: "Frank" (default), "Gumbel" or "Clayton". See details for more info.
 #' @param rho numeric parameter between -1 and 1, Spearman's correlation coefficient o Kendall Tau between the marginal distribution of the times to the two events E1 and E2. See details for more info.
-#' @param rho_type character indicating the type of correlation to be used: "Spearman" (default) or "Tau". See details for more info.
+#' @param rho_type character indicating the type of correlation to be used: "Spearman" (default) or "Kendall". See details for more info.
 #' @param followup_time numeric parameter indicating the maximum follow up time (in any unit). Default is 1.
 #' @param sample_size sample size for each arm (treated and control)
 #' 
@@ -38,7 +38,16 @@
 #' @details If \code{sample_size} is not an integer, it is rounded to the nearest integer.
 #'
 #'
-#'
+#' @examples
+#' # Simulate 10 times and censoring indicators for each arm
+#' simula_tte(p0_e1   = .59, p0_e2   = .74, 
+#'            HR_e1   = .91, HR_e2   = .77, 
+#'            beta_e1 = 1,   beta_e2 = 2, 
+#'            case    = 3,   rho     = .5,
+#'            copula  = 'Frank', rho_type  = 'Spearman',
+#'            sample_size = 10, followup_time = 2)
+
+
 simula_tte <- function(p0_e1, p0_e2, HR_e1, HR_e2, beta_e1=1, beta_e2=1, 
                            case, copula = 'Frank', rho=0.3, rho_type='Spearman',
                            followup_time=1,sample_size){
@@ -84,7 +93,7 @@ simula_tte <- function(p0_e1, p0_e2, HR_e1, HR_e2, beta_e1=1, beta_e2=1,
   ##-- Find parameters
   theta <- CopulaSelection(copula=copula,rho=rho,rho_type=rho_type)[[2]]
   MarginSelec <- MarginalsSelection(beta_e1,beta_e2,HR_e1,HR_e2,
-                                    p0_e1,p0_e2,case,rho=rho,theta=theta,copula=copula)
+                                    p0_e1,p0_e2,case,rho=rho,theta=theta,copula=copula, seed=NA)
   par_shape <- c(beta_e1,beta_e2,beta_e1,beta_e1)              # Weibull shape parameters
   par_scale <- c(MarginSelec[[5]][[2]],                        # Weibull scale parameters
                  MarginSelec[[6]][[2]],
@@ -151,5 +160,5 @@ simula_tte <- function(p0_e1, p0_e2, HR_e1, HR_e2, beta_e1=1, beta_e2=1,
                                       cbind(time_ce=TC1,status_ce=status_C1))))
   df_all$treated <- c(rep(0,sample_size),rep(1,sample_size))
 
-  return(invisible(df_all))
+  return(df_all)
 }
